==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkExtractUnstructuredGrid.java <==
// java wrapper for vtkExtractUnstructuredGrid object
//

package vtk;
import vtk.*;

public class vtkExtractUnstructuredGrid extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPointClipping_2(int id0);
  public void SetPointClipping(int id0)
    { SetPointClipping_2(id0); }

  private native int GetPointClipping_3();
  public int GetPointClipping()
    { return GetPointClipping_3(); }

  private native void PointClippingOn_4();
  public void PointClippingOn()
    { PointClippingOn_4(); }

  private native void PointClippingOff_5();
  public void PointClippingOff()
    { PointClippingOff_5(); }

  private native void SetCellClipping_6(int id0);
  public void SetCellClipping(int id0)
    { SetCellClipping_6(id0); }

  private native int GetCellClipping_7();
  public int GetCellClipping()
    { return GetCellClipping_7(); }

  private native void CellClippingOn_8();
  public void CellClippingOn()
    { CellClippingOn_8(); }

  private native void CellClippingOff_9();
  public void CellClippingOff()
    { CellClippingOff_9(); }

  private native void SetExtentClipping_10(int id0);
  public void SetExtentClipping(int id0)
    { SetExtentClipping_10(id0); }

  private native int GetExtentClipping_11();
  public int GetExtentClipping()
    { return GetExtentClipping_11(); }

  private native void ExtentClippingOn_12();
  public void ExtentClippingOn()
    { ExtentClippingOn_12(); }

  private native void ExtentClippingOff_13();
  public void ExtentClippingOff()
    { ExtentClippingOff_13(); }

  private native void SetPointMinimum_14(int id0);
  public void SetPointMinimum(int id0)
    { SetPointMinimum_14(id0); }

  private native int GetPointMinimumMinValue_15();
  public int GetPointMinimumMinValue()
    { return GetPointMinimumMinValue_15(); }

  private native int GetPointMinimumMaxValue_16();
  public int GetPointMinimumMaxValue()
    { return GetPointMinimumMaxValue_16(); }

  private native int GetPointMinimum_17();
  public int GetPointMinimum()
    { return GetPointMinimum_17(); }

  private native void SetPointMaximum_18(int id0);
  public void SetPointMaximum(int id0)
    { SetPointMaximum_18(id0); }

  private native int GetPointMaximumMinValue_19();
  public int GetPointMaximumMinValue()
    { return GetPointMaximumMinValue_19(); }

  private native int GetPointMaximumMaxValue_20();
  public int GetPointMaximumMaxValue()
    { return GetPointMaximumMaxValue_20(); }

  private native int GetPointMaximum_21();
  public int GetPointMaximum()
    { return GetPointMaximum_21(); }

  private native void SetCellMinimum_22(int id0);
  public void SetCellMinimum(int id0)
    { SetCellMinimum_22(id0); }

  private native int GetCellMinimumMinValue_23();
  public int GetCellMinimumMinValue()
    { return GetCellMinimumMinValue_23(); }

  private native int GetCellMinimumMaxValue_24();
  public int GetCellMinimumMaxValue()
    { return GetCellMinimumMaxValue_24(); }

  private native int GetCellMinimum_25();
  public int GetCellMinimum()
    { return GetCellMinimum_25(); }

  private native void SetCellMaximum_26(int id0);
  public void SetCellMaximum(int id0)
    { SetCellMaximum_26(id0); }

  private native int GetCellMaximumMinValue_27();
  public int GetCellMaximumMinValue()
    { return GetCellMaximumMinValue_27(); }

  private native int GetCellMaximumMaxValue_28();
  public int GetCellMaximumMaxValue()
    { return GetCellMaximumMaxValue_28(); }

  private native int GetCellMaximum_29();
  public int GetCellMaximum()
    { return GetCellMaximum_29(); }

  private native void SetExtent_30(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetExtent(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetExtent_30(id0,id1,id2,id3,id4,id5); }

  private native void SetExtent_31(double id0[]);
  public void SetExtent(double id0[])
    { SetExtent_31(id0); }

  private native double[] GetExtent_32();
  public double[] GetExtent()
    { return GetExtent_32(); }

  private native void SetMerging_33(int id0);
  public void SetMerging(int id0)
    { SetMerging_33(id0); }

  private native int GetMerging_34();
  public int GetMerging()
    { return GetMerging_34(); }

  private native void MergingOn_35();
  public void MergingOn()
    { MergingOn_35(); }

  private native void MergingOff_36();
  public void MergingOff()
    { MergingOff_36(); }

  private native void SetLocator_37(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_37(id0); }

  private native long GetLocator_38();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_38();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLocator_39();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_39(); }

  private native int GetMTime_40();
  public int GetMTime()
    { return GetMTime_40(); }

  public vtkExtractUnstructuredGrid() { super(); }

  public vtkExtractUnstructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkExtractUnstructuredGrid.java <==
// java wrapper for vtkExtractUnstructuredGrid object
//

package vtk;
import vtk.*;

public class vtkExtractUnstructuredGrid extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPointClipping_2(int id0);
  public void SetPointClipping(int id0)
    { SetPointClipping_2(id0); }

  private native int GetPointClipping_3();
  public int GetPointClipping()
    { return GetPointClipping_3(); }

  private native void PointClippingOn_4();
  public void PointClippingOn()
    { PointClippingOn_4(); }

  private native void PointClippingOff_5();
  public void PointClippingOff()
    { PointClippingOff_5(); }

  private native void SetCellClipping_6(int id0);
  public void SetCellClipping(int id0)
    { SetCellClipping_6(id0); }

  private native int GetCellClipping_7();
  public int GetCellClipping()
    { return GetCellClipping_7(); }

  private native void CellClippingOn_8();
  public void CellClippingOn()
    { CellClippingOn_8(); }

  private native void CellClippingOff_9();
  public void CellClippingOff()
    { CellClippingOff_9(); }

  private native void SetExtentClipping_10(int id0);
  public void SetExtentClipping(int id0)
    { SetExtentClipping_10(id0); }

  private native int GetExtentClipping_11();
  public int GetExtentClipping()
    { return GetExtentClipping_11(); }

  private native void ExtentClippingOn_12();
  public void ExtentClippingOn()
    { ExtentClippingOn_12(); }

  private native void ExtentClippingOff_13();
  public void ExtentClippingOff()
    { ExtentClippingOff_13(); }

  private native void SetPointMinimum_14(int id0);
  public void SetPointMinimum(int id0)
    { SetPointMinimum_14(id0); }

  private native int GetPointMinimumMinValue_15();
  public int GetPointMinimumMinValue()
    { return GetPointMinimumMinValue_15(); }

  private native int GetPointMinimumMaxValue_16();
  public int GetPointMinimumMaxValue()
    { return GetPointMinimumMaxValue_16(); }

  private native int GetPointMinimum_17();
  public int GetPointMinimum()
    { return GetPointMinimum_17(); }

  private native void SetPointMaximum_18(int id0);
  public void SetPointMaximum(int id0)
    { SetPointMaximum_18(id0); }

  private native int GetPointMaximumMinValue_19();
  public int GetPointMaximumMinValue()
    { return GetPointMaximumMinValue_19(); }

  private native int GetPointMaximumMaxValue_20();
  public int GetPointMaximumMaxValue()
    { return GetPointMaximumMaxValue_20(); }

  private native int GetPointMaximum_21();
  public int GetPointMaximum()
    { return GetPointMaximum_21(); }

  private native void SetCellMinimum_22(int id0);
  public void SetCellMinimum(int id0)
    { SetCellMinimum_22(id0); }

  private native int GetCellMinimumMinValue_23();
  public int GetCellMinimumMinValue()
    { return GetCellMinimumMinValue_23(); }

  private native int GetCellMinimumMaxValue_24();
  public int GetCellMinimumMaxValue()
    { return GetCellMinimumMaxValue_24(); }

  private native int GetCellMinimum_25();
  public int GetCellMinimum()
    { return GetCellMinimum_25(); }

  private native void SetCellMaximum_26(int id0);
  public void SetCellMaximum(int id0)
    { SetCellMaximum_26(id0); }

  private native int GetCellMaximumMinValue_27();
  public int GetCellMaximumMinValue()
    { return GetCellMaximumMinValue_27(); }

  private native int GetCellMaximumMaxValue_28();
  public int GetCellMaximumMaxValue()
    { return GetCellMaximumMaxValue_28(); }

  private native int GetCellMaximum_29();
  public int GetCellMaximum()
    { return GetCellMaximum_29(); }

  private native void SetExtent_30(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetExtent(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetExtent_30(id0,id1,id2,id3,id4,id5); }

  private native void SetExtent_31(double id0[]);
  public void SetExtent(double id0[])
    { SetExtent_31(id0); }

  private native double[] GetExtent_32();
  public double[] GetExtent()
    { return GetExtent_32(); }

  private native void SetMerging_33(int id0);
  public void SetMerging(int id0)
    { SetMerging_33(id0); }

  private native int GetMerging_34();
  public int GetMerging()
    { return GetMerging_34(); }

  private native void MergingOn_35();
  public void MergingOn()
    { MergingOn_35(); }

  private native void MergingOff_36();
  public void MergingOff()
    { MergingOff_36(); }

  private native void SetLocator_37(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_37(id0); }

  private native long GetLocator_38();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_38();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLocator_39();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_39(); }

  private native int GetMTime_40();
  public int GetMTime()
    { return GetMTime_40(); }

  public vtkExtractUnstructuredGrid() { super(); }

  public vtkExtractUnstructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}
